@@ -6,15 +6,15 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-scroll-on-drag
-;; Package-Version: 20250913.2251
-;; Package-Revision: 2df06478dc0a
+;; Package-Version: 20260108.1316
+;; Package-Revision: eb38193bbcbf
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
 
 ;; Interactive scrolling which can be canceled by pressing escape.
 
-;;; Usage
+;;; Usage:
 
 ;; (scroll-on-drag) ; Interactively scroll the current buffer
 ;;
@@ -47,7 +47,7 @@
   :group 'scrolling)
 
 (defcustom scroll-on-drag-style 'line-by-pixel
-  "The the method scrolling is calculated."
+  "The method used to calculate scrolling."
   :type
   '(choice (const :tag "Line" line)
            (const :tag "Line-By-Pixel" line-by-pixel)))
@@ -79,9 +79,9 @@
 (defcustom scroll-on-drag-mode-line-format nil
   "The `mode-line-format' to use or nil to leave the `mode-line-format' unchanged.
 
-This can be useful to use a simplified or event disabling the mode-line
+This can be useful for simplifying or even disabling the mode-line
 while scrolling, as a complex mode-line can interfere with smooth scrolling."
-  :type '(choice (const nil) string))
+  :type '(choice (const nil) sexp))
 
 (defcustom scroll-on-drag-pre-hook nil
   "List of functions to be called when `scroll-on-drag' starts."
@@ -102,17 +102,18 @@ while scrolling, as a complex mode-line can interfere with smooth scrolling."
 ;; Generic scrolling functions.
 ;;
 ;; It would be nice if this were part of a more general library.
-;; Optionally also move the point is needed because _not_ doing this
-;; makes the window constraint so the point stays within it.
+;; Support for moving the point is needed because failing to do this
+;; makes the window constrained so the point stays within it.
 
 ;; Per-line Scroll.
-;; return remainder of lines to scroll (matching forward-line).
+;; Return remainder of lines to scroll (matching forward-line).
 (defun scroll-on-drag--scroll-by-lines (window lines also-move-point)
-  "Line based scroll that optionally move the point.
-Argument WINDOW The window to scroll.
-Argument LINES The number of lines to scroll (signed).
-Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
-  (declare (important-return-value nil))
+  "Line based scroll that optionally moves the point.
+WINDOW The window to scroll.
+LINES The number of lines to scroll (signed).
+ALSO-MOVE-POINT When non-nil, move the POINT as well.
+Return remainder of lines to scroll (matching `forward-line')."
+  (declare (important-return-value t))
   (let ((lines-remainder 0))
     (when also-move-point
       (let ((lines-point-remainder (forward-line lines)))
@@ -130,18 +131,19 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
           (forward-line (- lines-remainder)))))
     lines-remainder))
 
-;; Per-pixel Scroll,
-;; return remainder of lines to scroll (matching forward-line).
+;; Per-pixel Scroll.
+;; Return remainder of lines to scroll (matching forward-line).
 (defun scroll-on-drag--scroll-by-pixels (window char-height delta-px also-move-point)
-  "Line based scroll that optionally move the point.
-Argument WINDOW The window to scroll.
-Argument CHAR-HEIGHT The result of `frame-char-height'.
-Argument DELTA-PX The number of pixels to scroll (signed).
-Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
+  "Pixel based scroll that optionally moves the point.
+WINDOW The window to scroll.
+CHAR-HEIGHT The result of `frame-char-height'.
+DELTA-PX The number of pixels to scroll (signed).
+ALSO-MOVE-POINT When non-nil, move the POINT as well.
+Return remainder of lines to scroll (matching `forward-line')."
   (declare (important-return-value nil))
   (cond
    ((< delta-px 0)
-    (let* ((scroll-px-prev (- char-height (window-vscroll nil t))) ; flip.
+    (let* ((scroll-px-prev (- char-height (window-vscroll window t))) ; flip.
            (scroll-px-next (+ scroll-px-prev (- delta-px))) ; flip.
            (lines (/ scroll-px-next char-height))
            (scroll-px (- scroll-px-next (* lines char-height)))
@@ -155,7 +157,7 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
       (set-window-vscroll window (- char-height scroll-px) t)
       (- lines-remainder)))
    ((> delta-px 0)
-    (let* ((scroll-px-prev (window-vscroll nil t))
+    (let* ((scroll-px-prev (window-vscroll window t))
            (scroll-px-next (+ scroll-px-prev delta-px))
            (lines (/ scroll-px-next char-height))
            (scroll-px (- scroll-px-next (* lines char-height)))
@@ -166,7 +168,7 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
           (setq scroll-px char-height)))
       (set-window-vscroll window scroll-px t)
       lines-remainder))
-   ;; no lines scrolled.
+   ;; No lines scrolled.
    (t
     0)))
 
@@ -197,7 +199,7 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
 
 (defmacro scroll-on-drag--with-evil-visual-mode-hack (visual-line-data &rest body)
   "Execute BODY without evil-visual-mode line constraints.
-Run when MARK is non-nil.
+Run when VISUAL-LINE-DATA is non-nil.
 VISUAL-LINE-DATA is the result of `scroll-on-drag--evil-visual-line-data'."
   (declare (indent 1))
   `(unwind-protect
@@ -218,8 +220,7 @@ The result should be passed to `scroll-on-drag--goal-column-restore'."
    (current-column)
    (or goal-column
        (cond
-        ((and temporary-goal-column
-              (memq last-command (list 'next-line 'previous-line 'line-move)))
+        ((and temporary-goal-column (memq last-command '(next-line previous-line line-move)))
          (cond
           ((consp temporary-goal-column)
            (car temporary-goal-column))
@@ -242,15 +243,15 @@ The result should be passed to `scroll-on-drag--goal-column-restore'."
 
 
 ;; ---------------------------------------------------------------------------
-;; Public Functions
+;; Internal Implementation
 
 (defun scroll-on-drag--impl ()
-  "Interactively scroll (typically on click event).
-Returns true when scrolling took place, otherwise nil."
+  "Interactively scroll, typically on click event.
+Returns non-nil when scrolling took place, otherwise nil."
   (declare (important-return-value t))
   (let* ((scroll-timer nil)
 
-         ; Don't run unnecessary logic when scrolling.
+         ;; Don't run unnecessary logic when scrolling.
          (inhibit-point-motion-hooks t)
          ;; Only draw explicitly once all actions have been done.
          (inhibit-redisplay t)
@@ -260,7 +261,7 @@ Returns true when scrolling took place, otherwise nil."
          (this-frame-char-height (frame-char-height))
          (this-frame-char-height-as-float (float this-frame-char-height))
 
-         ;; Reset's when pressing Escape.
+         ;; Resets when pressing Escape.
          (has-scrolled nil)
          ;; Doesn't reset (so we can detect clicks).
          (has-scrolled-real nil)
@@ -360,7 +361,6 @@ Returns true when scrolling took place, otherwise nil."
             (lambda (self-fn)
               (let ((lines delta))
                 (unless (zerop lines)
-                  (decf delta-px-accum (* lines this-frame-char-height))
                   (let ((lines-remainder (scroll-on-drag--scroll-by-lines this-window lines t)))
                     (unless (zerop (- lines lines-remainder))
                       (scroll-on-drag--force-redisplay-with-hooks)))))
@@ -441,7 +441,7 @@ Returns true when scrolling took place, otherwise nil."
 
          ;; Workaround for bad pixel scrolling performance
          ;; when the cursor is partially outside the view.
-         (scroll-consrtain-point-below-window-start-fn
+         (scroll-constrain-point-below-window-start-fn
           (lambda ()
             (let ((lines-from-top (count-lines (window-start) (pos-bol))))
               (when (> scroll-margin lines-from-top)
@@ -477,7 +477,7 @@ Returns true when scrolling took place, otherwise nil."
                        ;; Clamp point to scroll bounds on first scroll,
                        ;; allow pressing 'Esc' to use unclamped position.
                        (when scroll-on-drag-smooth
-                         (funcall scroll-consrtain-point-below-window-start-fn))
+                         (funcall scroll-constrain-point-below-window-start-fn))
                        (setq has-scrolled t))
                      (unless has-scrolled-real
                        (let ((inhibit-redisplay nil))
@@ -531,7 +531,7 @@ This requires a separate code path to run pre/post logic."
       (scroll-on-drag--impl)))))
 
 (defun scroll-on-drag--impl-with-mode-line-format ()
-  "Call `mode-line-format' with mode-line override."
+  "Conditionally override `mode-line-format'."
   (declare (important-return-value nil))
 
   (cond
@@ -552,6 +552,11 @@ This requires a separate code path to run pre/post logic."
    (t
     (scroll-on-drag--impl-with-mode-line-format))))
 
+
+;; ---------------------------------------------------------------------------
+;; Public Functions
+
+;;;###autoload
 (defun scroll-on-drag (&optional event)
   "Main scroll on drag function.
 
@@ -561,15 +566,15 @@ when `scroll-on-drag-follow-mouse' is non-nil."
   (interactive "e")
   (let ((scroll-win nil))
     (when scroll-on-drag-follow-mouse
-      (setq scroll-win (posn-window (or (event-start event) last-input-event))))
-
+      (when-let* ((event-any (or event last-input-event)))
+        (setq scroll-win (posn-window (event-start event-any)))))
     (scroll-on-drag--impl-with-window scroll-win)))
 
 
 ;;;###autoload
 (defmacro scroll-on-drag-with-fallback (&rest body)
   "A macro to scroll and perform a different action on click.
-Optional argument BODY Hello."
+Optional argument BODY is executed when scrolling did not take place."
   `(lambda ()
      (interactive)
      (unless (scroll-on-drag)
